==> qt-win-opensource-src-4.0.1.zip: qt-win-opensource-src-4.0.1/src/gui/text/qscriptengine_win.cpp <==
/****************************************************************************
**
** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
**
** This file is part of the QtGui module of the Qt Toolkit.
**
** This file may be used under the terms of the GNU General Public
** License version 2.0 as published by the Free Software Foundation
** and appearing in the file LICENSE.GPL included in the packaging of
** this file.  Please review the following information to ensure GNU
** General Public Licensing requirements will be met:
** http://www.trolltech.com/products/qt/opensource.html
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

const q_scriptEngine qt_scriptEngines[] = {
    // Common
    { basic_shape, basic_attributes },
    // Hebrew
    { basic_shape, basic_attributes },
    // Arabic
    { arabic_shape, arabic_attributes },
    // Syriac
    { basic_shape, basic_attributes },
    // Thaana
    { basic_shape, basic_attributes },
    // Devanagari
    { basic_shape, basic_attributes },
    // Bengali
    { basic_shape, basic_attributes },
    // Gurmukhi
    { basic_shape, basic_attributes },
    // Gujarati
    { basic_shape, basic_attributes },
    // Oriya
    { basic_shape, basic_attributes },
    // Tamil
    { basic_shape, basic_attributes },
    // Telugu
    { basic_shape, basic_attributes },
    // Kannada
    { basic_shape, basic_attributes },
    // Malayalam
    { basic_shape, basic_attributes },
    // Sinhala
    { basic_shape, basic_attributes },
    // Thai
    { basic_shape, basic_attributes },
    // Lao
    { basic_shape, basic_attributes },
    // Tibetan
    { basic_shape, basic_attributes },
    // Myanmar
    { basic_shape, basic_attributes },
    // Hangul
    { basic_shape, basic_attributes },
    // Khmer
    { basic_shape, basic_attributes }

#if 0
    // ### What about this one?
    // Unicode
    { unicode_shape, basic_attributes }
#endif

};

==> qt-win-opensource-src-4.1.0-rc1.zip: qt-win-opensource-src-4.1.0-rc1/src/gui/text/qscriptengine_win.cpp <==
/****************************************************************************
**
** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
**
** This file is part of the QtGui module of the Qt Toolkit.
**
** This file may be used under the terms of the GNU General Public
** License version 2.0 as published by the Free Software Foundation
** and appearing in the file LICENSE.GPL included in the packaging of
** this file.  Please review the following information to ensure GNU
** General Public Licensing requirements will be met:
** http://www.trolltech.com/products/qt/opensource.html
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

const q_scriptEngine qt_scriptEngines[] = {
    // Common
    { basic_shape, 0 },
    // Hebrew
    { hebrew_shape, 0 },
    // Arabic
    { arabic_shape, 0 },
    // Syriac
    { basic_shape, 0 },
    // Thaana
    { basic_shape, 0 },
    // Devanagari
    { basic_shape, 0 },
    // Bengali
    { basic_shape, 0 },
    // Gurmukhi
    { basic_shape, 0 },
    // Gujarati
    { basic_shape, 0 },
    // Oriya
    { basic_shape, 0 },
    // Tamil
    { basic_shape, 0 },
    // Telugu
    { basic_shape, 0 },
    // Kannada
    { basic_shape, 0 },
    // Malayalam
    { basic_shape, 0 },
    // Sinhala
    { basic_shape, 0 },
    // Thai
    { basic_shape, 0 },
    // Lao
    { basic_shape, 0 },
    // Tibetan
    { basic_shape, 0 },
    // Myanmar
    { basic_shape, 0 },
    // Hangul
    { basic_shape, 0 },
    // Khmer
    { basic_shape, 0 }
};
